import setuptools

setuptools.setup(
    name="pynewyear",
    version="1.0.0",
    author="Baboshin Sergey",
    author_email="ijustbsd@gmail.com",
    description="Happy New Year! 🎄",
    url="https://github.com/ijustbsd/pynewyear",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.7'
)
